Class: BuckKnife::Commands::EucaCreate
- Includes:
- Base
- Defined in:
- lib/buckknife/commands/euca_create.rb
Instance Attribute Summary
Attributes inherited from Create
Instance Method Summary collapse
-
#command ⇒ Object
-Z, --availability-zone ZONE The Availability Zone --bootstrap-version VERSION The version of Chef to install -N, --node-name NAME The Chef node name for your new node -s, --server-url URL Chef Server URL -k, --key KEY API Client Key --color Use colored output -c, --config CONFIG The configuration file to use --defaults Accept default values for all questions -d, --distro DISTRO Bootstrap a distro using a template -e, --editor EDITOR Set the editor to use for interactive commands -E, --environment ENVIRONMENT Set the Chef environment -f, --flavor FLAVOR The flavor of server (m1.small, m1.medium, etc) -F, --format FORMAT Which format to use for output -i IDENTITY_FILE The SSH identity file used for authentication --identity-file -I, --image IMAGE The AMI for the server --no-color Don't use colors in the output -n, --no-editor Do not open EDITOR, just accept the data as is --no-host-key-verify Disable host key verification -u, --user USER API Client Username --prerelease Install the pre-release chef gems --print-after Show the data after a destructive operation -r, --run-list RUN_LIST Comma separated list of roles/recipes to apply -G, --groups X,Y,Z The security groups for this server -S, --ssh-key KEY The Eucalyptus SSH key id -P, --ssh-password PASSWORD The ssh password -x, --ssh-user USERNAME The ssh username --template-file TEMPLATE Full path to location of template to use -V, --verbose More verbose output.
Methods included from Base
#base_run_list, #build_run_list, #to_s
Methods inherited from Create
Instance Method Details
#command ⇒ Object
-Z, --availability-zone ZONE The Availability Zone --bootstrap-version VERSION The version of Chef to install -N, --node-name NAME The Chef node name for your new node -s, --server-url URL Chef Server URL -k, --key KEY API Client Key --color Use colored output -c, --config CONFIG The configuration file to use --defaults Accept default values for all questions -d, --distro DISTRO Bootstrap a distro using a template -e, --editor EDITOR Set the editor to use for interactive commands -E, --environment ENVIRONMENT Set the Chef environment -f, --flavor FLAVOR The flavor of server (m1.small, m1.medium, etc) -F, --format FORMAT Which format to use for output -i IDENTITY_FILE The SSH identity file used for authentication --identity-file -I, --image IMAGE The AMI for the server --no-color Don't use colors in the output -n, --no-editor Do not open EDITOR, just accept the data as is --no-host-key-verify Disable host key verification -u, --user USER API Client Username --prerelease Install the pre-release chef gems --print-after Show the data after a destructive operation -r, --run-list RUN_LIST Comma separated list of roles/recipes to apply -G, --groups X,Y,Z The security groups for this server -S, --ssh-key KEY The Eucalyptus SSH key id -P, --ssh-password PASSWORD The ssh password -x, --ssh-user USERNAME The ssh username --template-file TEMPLATE Full path to location of template to use -V, --verbose More verbose output. Use twice for max verbosity -v, --version Show chef version -y, --yes Say yes to all prompts for confirmation -h, --help Show this message
39 40 41 42 43 44 |
# File 'lib/buckknife/commands/euca_create.rb', line 39 def command super.tap do |c| c.opt '-i', identity_file if identity_file c.opt '-Z', availability_zone if availability_zone end end |