Class: BuckKnife::Commands::RackspaceCreate

Inherits:
Create
  • Object
show all
Includes:
Base
Defined in:
lib/buckknife/commands/rackspace_create.rb

Instance Attribute Summary

Attributes inherited from Create

#node, #project

Instance Method Summary collapse

Methods included from Base

#base_run_list, #build_run_list, #to_s

Methods inherited from Create

[], #chef_server_url

Instance Method Details

#commandObject

--bootstrap-version VERSION The version of Chef to install -N, --node-name NAME The Chef node name for your new node -s, --server-url URL Chef Server URL -k, --key KEY API Client Key --color Use colored output -c, --config CONFIG The configuration file to use --defaults Accept default values for all questions -d, --distro DISTRO Bootstrap a distro using a template; default is 'ubuntu10.04-gems' -e, --editor EDITOR Set the editor to use for interactive commands -E, --environment ENVIRONMENT Set the Chef environment -f, --flavor FLAVOR The flavor of server; default is 2 (512 MB) -F, --format FORMAT Which format to use for output -I, --image IMAGE The image of the server --no-color Don't use colors in the output -n, --no-editor Do not open EDITOR, just accept the data as is -u, --user USER API Client Username --prerelease Install the pre-release chef gems --print-after Show the data after a destructive operation --rackspace-api-auth-url URL Your rackspace API auth url; default is 'auth.api.rackspacecloud.com' -K, --rackspace-api-key KEY Your rackspace API key -A USERNAME Your rackspace API username --rackspace-api-username -r, --run-list RUN_LIST Comma separated list of roles/recipes to apply -S, --server-name NAME The server name -P, --ssh-password PASSWORD The ssh password -x, --ssh-user USERNAME The ssh username; default is 'root' --template-file TEMPLATE Full path to location of template to use --sudo Execute the bootstrap via sudo -V, --verbose More verbose output. Use twice for max verbosity -v, --version Show chef version -y, --yes Say yes to all prompts for confirmation -h, --help Show this message



39
40
41
42
43
44
45
# File 'lib/buckknife/commands/rackspace_create.rb', line 39

def command
  super.tap do |c|
    c.opt '-S', node.name
    c.opt '-K', project.rs_api_key
    c.opt '-A', project.rs_api_username
  end
end